Nxpy Temp File
==============

You can install the library with pip::

    pip install nxpy-temp-file

*Nxpy Temp File* provides context managers for temporary files and directories.

The library's documentation is available on
`ReadTheDocs <https://nxpy.readthedocs.io/en/latest/temp_file.html>`_.
